"""

@FileName: adb_tools.py
@Author: chenxiaodong
@CreatTime: 2020/9/14 16:23
@Descriptions: 

"""


class adb_tools:
    def __init__(self):
        """
        :param:
        :return:

        """
        pass

    def adb_kill_server(self):
        """
        :param:
        :return:

        """
        pass

    def adb_start_server(self):
        """
        :param:
        :return:

        """
        pass

    def adb_shell(self):
        """
        :param:
        :return:

        """
        pass

    def adb_connect(self):
        """
        :param:
        :return:

        """
        pass

    def adb_devices(self):
        """
        :param:
        :return:

        """
        pass

    def adb_install(self):
        """
        :param: 
        :return: 
        
        """
        pass

    def adb_uninstall(self):
        """
        :param:
        :return:

        """
        pass



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="wasu_test",
    version="1.0",
    author="XiaoDong Chen",
    author_email="chenxiaodong@wasu.com",
    description="The Wasu Auto TestFrameWork",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="",
    packages=setuptools.find_packages(),
    install_requires=['yaml'],
    entry_points={

    },
    classifiers=(
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ),
)


"""

@FileName: console_line_tools.py
@Author: chenxiaodong
@CreatTime: 2020/9/14 16:23
@Descriptions: 

"""


class console_line_tools:

    def __init__(self):
        """
        :param:
        :return:

        """
        pass
